pub struct SearchToolOutput {
pub results: Vec<SearchResultCard>,
pub total_returned: usize,
}Fields
results: Vec<SearchResultCard>total_returned: usizeTrait Implementations
Sourceimpl Clone for SearchToolOutput
impl Clone for SearchToolOutput
Sourcefn clone(&self) -> SearchToolOutput
fn clone(&self) -> SearchToolOutput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SearchToolOutput
impl Debug for SearchToolOutput
Sourceimpl<'de> Deserialize<'de> for SearchToolOutput
impl<'de> Deserialize<'de> for SearchToolOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SearchToolOutput
impl JsonSchema for SearchToolOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SearchToolOutput
impl PartialEq for SearchToolOutput
Sourcefn eq(&self, other: &SearchToolOutput) -> bool
fn eq(&self, other: &SearchToolOutput) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for SearchToolOutput
impl Serialize for SearchToolOutput
impl Eq for SearchToolOutput
impl StructuralPartialEq for SearchToolOutput