pub struct SummarizeToolOutput {
pub markdown: String,
pub text: Option<String>,
pub source_url: Option<String>,
}Fields
markdown: Stringtext: Option<String>source_url: Option<String>Trait Implementations
Sourceimpl Clone for SummarizeToolOutput
impl Clone for SummarizeToolOutput
Sourcefn clone(&self) -> SummarizeToolOutput
fn clone(&self) -> SummarizeToolOutput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SummarizeToolOutput
impl Debug for SummarizeToolOutput
Sourceimpl<'de> Deserialize<'de> for SummarizeToolOutput
impl<'de> Deserialize<'de> for SummarizeToolOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SummarizeToolOutput
impl JsonSchema for SummarizeToolOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SummarizeToolOutput
impl PartialEq for SummarizeToolOutput
Sourcefn eq(&self, other: &SummarizeToolOutput) -> bool
fn eq(&self, other: &SummarizeToolOutput) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for SummarizeToolOutput
impl Serialize for SummarizeToolOutput
impl Eq for SummarizeToolOutput
impl StructuralPartialEq for SummarizeToolOutput